.. py:currentmodule:: Orange.bio.obiProb

.. index:: binomial distribution
.. index:: hypergeometric distribution
.. index:: FDR
.. index:: Bonferroni

********************************************************
Probability distributions and corrections (:mod:`obiProb`)
********************************************************


.. autoclass:: Binomial
   :members: __call__, p_value

.. autoclass:: Hypergeometric
   :members: __call__, p_value

.. autofunction:: FDR

.. autofunction:: Bonferroni



